move

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	InstallerVersionFilePath = "agent/installer.version"
	CurrentDir               = "agent/bin/current"
)

Variables

This section is empty.

Functions

func CopyByTechnology added in v1.0.2

func CopyByTechnology(log logr.Logger, from string, to string, technology string) error
func CreateCurrentSymlink(log logr.Logger, targetDir string) error

CreateCurrentSymlink finds the version of the CodeModule in the `targetDir` (in the installer.version file) and creates a "current" symlink in the agent/bin folder that points to the agent/bin/<version> subfolder. this is needed for the nginx use-case.

func SimpleCopy added in v1.0.2

func SimpleCopy(log logr.Logger, from, to string) error

Types

type ArchEntries added in v0.2.0

type ArchEntries map[string][]FileEntry

type CopyFunc added in v1.1.2

type CopyFunc func(log logr.Logger, from, to string) error

func Atomic added in v1.0.2

func Atomic(work string, copyFunc CopyFunc) CopyFunc

func CopyByTechnologyWrapper added in v1.0.2

func CopyByTechnologyWrapper(technology string) CopyFunc

func CreateCurrentSymlinkOnCopy added in v1.2.0

func CreateCurrentSymlinkOnCopy(copyFunc CopyFunc) CopyFunc

CreateCurrentSymlinkOnCopy wraps the given copy function to create the current symlink right after the copy operation. The copy wrapper is used to create the current symlink in the working directory before it is moved to the target directory.

type FileEntry added in v0.2.0

type FileEntry struct {
	Path    string `json:"path"`
	Version string `json:"version"`
	MD5     string `json:"md5"`
}

type Manifest added in v0.2.0

type Manifest struct {
	Technologies TechEntries `json:"technologies"`
	Version      string      `json:"version"`
}

type TechEntries added in v0.2.0

type TechEntries map[string]ArchEntries

Jump to