Documentation
¶
Index ¶
Constants ¶
const ( InstallerVersionFilePath = "agent/installer.version" CurrentDir = "agent/bin/current" )
Variables ¶
This section is empty.
Functions ¶
func CopyByTechnology ¶ added in v1.0.2
func CreateCurrentSymlink ¶ added in v1.0.3
CreateCurrentSymlink finds the version of the CodeModule in the `targetDir` (in the installer.version file) and creates a "current" symlink in the agent/bin folder that points to the agent/bin/<version> subfolder. this is needed for the nginx use-case.
Types ¶
type ArchEntries ¶ added in v0.2.0
type CopyFunc ¶ added in v1.1.2
func CopyByTechnologyWrapper ¶ added in v1.0.2
func CreateCurrentSymlinkOnCopy ¶ added in v1.2.0
CreateCurrentSymlinkOnCopy wraps the given copy function to create the current symlink right after the copy operation. The copy wrapper is used to create the current symlink in the working directory before it is moved to the target directory.
type Manifest ¶ added in v0.2.0
type Manifest struct {
Technologies TechEntries `json:"technologies"`
Version string `json:"version"`
}
type TechEntries ¶ added in v0.2.0
type TechEntries map[string]ArchEntries
Click to show internal directories.
Click to hide internal directories.